@@ -1,4 +1,10 @@
+import logging
+
 import rasterio
+import rasterio.env
+
+
+logging.basicConfig(level=logging.DEBUG)
 
 def test_band():
     with rasterio.open('tests/data/RGB.byte.tif') as src:
@@ -7,4 +13,3 @@ def test_band():
         assert b.bidx == 1
         assert b.dtype in src.dtypes
         assert b.shape == src.shape
-
