@@ -103,7 +103,7 @@ def test_file_in_handler_with_vfs():
     uri = 'zip://tests/data/files.zip!/RGB.byte.tif'
     ctx = MockContext()
     retval = file_in_handler(ctx, 'INPUT', uri)
-    assert retval.startswith('zip:///')
+    assert retval.startswith('zip://')
     assert 'tests/data/files.zip!/RGB.byte.tif' in retval
 
 
